@@ -19,13 +19,12 @@
 
 #include "favicons.h"
 
-#include "bookmarkiterator.h"
 #include "faviconupdater.h"
 #include "kbookmarkmodel/commands.h"
 #include "kbookmarkmodel/model.h"
 
 #include "keditbookmarks_debug.h"
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 FavIconsItrHolder::FavIconsItrHolder(QObject* parent, KBookmarkModel* model)
     : BookmarkIteratorHolder(parent, model)
