@@ -23,24 +23,22 @@
 #include "importers.h"
 #include "globalbookmarkmanager.h"
 
-#include "kbookmarkmodel/commands.h"
 #include "toplevel.h" // for KEBApp
 #include "kbookmarkmodel/model.h"
 
 #include <QFileDialog>
 #include "keditbookmarks_debug.h"
-#include <klocalizedstring.h>
 
-#include <kmessagebox.h>
+#include <KMessageBox>
 
-#include <kbookmark.h>
-#include <kbookmarkmanager.h>
+#include <KBookmark>
+#include <KBookmarkManager>
 
 #include <kbookmarkimporter.h>
 #include <kbookmarkimporter_ie.h>
 #include <kbookmarkimporter_opera.h>
 //#include <kbookmarkimporter_crash.h>
-#include <kbookmarkdombuilder.h>
+#include <KBookmarkDomBuilder>
 #include <kbookmarkimporter_ns.h>
 #include <QStandardPaths>
 
